#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_HYPOT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_HYPOT_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/hypot.hpp>

#endif
